@@ -22,7 +22,7 @@
  * Author:      Mladen Turk <mturk@apache.org>                             *
  * Author:      Rainer Jung <rjung@apache.org>                             *
  * Based on:                                                               *
- * Version:     $Revision: 1665454 $                                          *
+ * Version:     $Revision: 1760669 $                                          *
  ***************************************************************************/
 
 #include "jk_pool.h"
@@ -745,7 +745,7 @@ static int JK_METHOD maintain_workers(jk_worker_t *p, time_t now, int global, jk
          * before the interval has passed, we allow a little tolerance.
          */
         if (global == JK_TRUE) {
-            time_t exponent = JK_LB_DECAY_MULT * difftime(now, lb->s->last_maintain_time) / lb->maintain_time;
+            time_t exponent = JK_LB_DECAY_MULT * ((long)difftime(now, lb->s->last_maintain_time)) / lb->maintain_time;
             lb->s->last_maintain_time = now;
 
             if (JK_IS_DEBUG_LEVEL(l))
@@ -1349,11 +1349,6 @@ static int JK_METHOD service(jk_endpoint_t *e,
                 jk_uint64_t rd = 0;
                 jk_uint64_t wr = 0;
                 int busy;
-                /* Reset endpoint read and write sizes for
-                 * this request.
-                 */
-                end->rd = end->wr = 0;
-                end->recoverable = JK_TRUE;
                 if (p->worker->lblock == JK_LB_LOCK_PESSIMISTIC)
                     jk_shm_lock();
 
@@ -1655,7 +1650,7 @@ static int JK_METHOD service(jk_endpoint_t *e,
                     jk_log(l, JK_LOG_INFO,
                            "All tomcat instances failed, no more workers "
                            "left for recovery (attempt=%d, retry=%d)",
-                           attempt, retry);
+                           attempt + 1, retry);
                     *is_error = JK_HTTP_SERVER_BUSY;
                     rc = JK_FALSE;
                 }
@@ -1664,7 +1659,7 @@ static int JK_METHOD service(jk_endpoint_t *e,
                 jk_log(l, JK_LOG_INFO,
                        "All tomcat instances failed, no more workers "
                        "left (attempt=%d, retry=%d)",
-                       attempt, retry);
+                       attempt + 1, retry);
                 *is_error = JK_HTTP_SERVER_BUSY;
                 rc = JK_FALSE;
             }
